==> 2.4.11.tar.gz: cloudlog/application/language/russian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Внимание: вам нужно назначить активный профиль месторасположения станции.';

$lang['notice_turn_the_radio_on'] = 'За сегодня ни одного QSO, время вернуться к радио!';

$lang['general_word_important'] = 'Важно';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Информация';
$lang['general_word_choose_file'] = 'Выберите файл';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Дата';
$lang['general_word_time'] = 'Время';
$lang['general_word_datetime'] = 'Дата/Время';
$lang['general_word_none'] = '-';
$lang['general_word_name'] = 'Имя';
$lang['general_word_location'] = 'QTH';
$lang['general_word_comment'] = 'Комментарий';
$lang['general_word_general'] = 'Общее';
$lang['general_word_satellite'] = 'Спутник';
$lang['general_word_satellite_short'] = 'Спутн.';
$lang['general_word_notes'] = 'Заметки';
$lang['general_word_country'] = 'Страна';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Всего';
$lang['general_word_year'] = 'Год';
$lang['general_word_month'] = 'Месяц';

$lang['general_word_worked'] = 'Сработано';
$lang['general_word_confirmed'] = 'Подтверждено';
$lang['general_word_needed'] = 'Необходимо';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Нет';
$lang['general_word_yes'] = 'Да';
$lang['general_word_method'] = 'Метод';

$lang['general_word_sent'] = 'Отправлено';
$lang['general_word_received'] = 'Принято';
$lang['general_word_requested'] = 'Запрошено';
$lang['general_word_queued'] = 'В очереди';
$lang['general_word_invalid_ignore'] = 'Некорректно (Игнорировать)';

$lang['general_word_qslcard'] = 'QSL карточка';
$lang['general_word_qslcard_management'] = 'QSL менеджемент';
$lang['general_word_qslcards'] = 'QSL карточки';
$lang['general_word_qslcard_direct'] = 'Напрямую';
$lang['general_word_qslcard_bureau'] = 'Бюро';
$lang['general_word_qslcard_electronic'] = 'Электронное';
$lang['general_word_qslcard_manager'] = 'Менеджер';
$lang['general_word_qslcard_via'] = 'через';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_qso_data'] = 'QSO Data';
$lang['general_word_details'] = 'Details';

$lang['general_edit_qso'] = 'Редактировать QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Отметить QSL полученной (через бюро)';
$lang['general_mark_qsl_rx_direct'] = 'Отметить QSL полученной (напрямую)';
$lang['general_mark_qsl_rx_electronic'] = 'Отметить QSL полученной (электронно)';
$lang['general_mark_qsl_tx_bureau'] = 'Отметить QSL отправленной (через бюро)';
$lang['general_mark_qsl_tx_direct'] = 'Отметить QSL отправленой (напрямую)';
$lang['general_mark_qsl_requested'] = 'Отметить запрос QSL-карточки';
$lang['general_mark_qsl_requested_bureau'] = 'Отметить запрос QSL-карточки (через бюро)';
$lang['general_mark_qsl_requested_direct'] = 'Отметить запрос QSL-карточки (напрямую)';
$lang['general_mark_qsl_not_required'] = 'Отметить QSL-карточка не требуется';

$lang['general_delete_qso'] = 'Удалить QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Суммарная дистанция';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Месторасположение станции';

$lang['gen_hamradio_cq'] = "CQ";
// ham radio terms
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Станция';

$lang['gen_hamradio_call'] = 'Позывной';
$lang['gen_hamradio_callsign'] = 'Позывной';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Вид модуляции';
$lang['gen_hamradio_rst_sent'] = 'Отправлено';
$lang['gen_hamradio_rst_rcvd'] = 'Получено';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band'] = 'Диапазон';
$lang['gen_hamradio_band_rx'] = 'Диапазон (RX)';
$lang['gen_hamradio_frequency'] = 'Частота';
$lang['gen_hamradio_frequency_rx'] = 'Частота (RX)';
$lang['gen_hamradio_radio'] = 'Радио';
$lang['gen_hamradio_rsts'] = 'RST (отправлено)';
$lang['gen_hamradio_rstr'] = 'RST (принято)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Локатор';
$lang['gen_hamradio_transmit_power'] = 'Мощность передачи (Вт)';
$lang['gen_hamradio_propagation_mode'] = 'Тип прохождения';

$lang['gen_hamradio_satellite_name'] = 'Название спутника';
$lang['gen_hamradio_satellite_mode'] = 'Режим работы спутника';

$lang['gen_hamradio_logbook'] = 'Журнал';
$lang['gen_hamradio_zones'] = 'Zones';

$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Удалённые DXCC';
$lang['gen_hamradio_continent'] = 'Континент';
$lang['gen_hamradio_usa_state'] = 'Штат США';
$lang['gen_hamradio_county_reference'] = 'Графство США';
$lang['gen_hamradio_iota_reference'] = 'IOTA справочник';
$lang['gen_hamradio_sota_reference'] = 'SOTA Справочник';
$lang['gen_hamradio_wwff_reference'] = 'WWFF справочник';
$lang['gen_hamradio_pota_reference'] = 'POTA справочник';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Штат';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare'] = 'Квадрат';
$lang['gen_hamradio_distance'] = 'Дистанция';
$lang['gen_hamradio_operator'] = 'Оператор';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = '';
$lang['dashboard_qsos_today'] = 'QSOs сегодня!';
$lang['dashboard_qso_breakdown'] = 'Статистика QSO';
$lang['gen_to_date'] = 'To date';
$lang['dashboard_countries_breakdown'] = 'Статистика по странам';

$lang['gen_from_date'] = 'Начиная с даты';

$lang['gen_this_qso_was_confirmed_on'] = 'Это QSO было подтверждено:';

$lang['error_no_logbook_found'] = 'Журнал не найден. Вам необходимо опрелелить журнал в разделе Журналы станций! Тут:';

$lang['copy_to_clipboard'] = 'Скопировать в буфер обмена';

$lang['africa'] = 'Африка';
$lang['antarctica'] = 'Антарктика';
$lang['asia'] = 'Азия';
$lang['europe'] = 'Европа';
$lang['northamerica'] = 'Северная Америка';
$lang['oceania'] = 'Океания';
$lang['southamerica'] = 'Южная Америка';

$lang['gen_band_selection'] = 'Выбор диапазона';
$lang['general_word_today'] = 'Today';

==> 2.5.2.tar.gz: cloudlog/application/language/russian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Внимание: вам нужно назначить активный профиль месторасположения станции.';

$lang['notice_turn_the_radio_on'] = 'За сегодня ни одного QSO, время вернуться к радио!';

$lang['general_word_important'] = 'Важно';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Информация';
$lang['general_word_choose_file'] = 'Выберите файл';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";

$lang['general_word_date'] = 'Дата';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Время';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Дата/Время';
$lang['general_word_none'] = '-';
$lang['general_word_name'] = 'Имя';
$lang['general_word_location'] = 'QTH';
$lang['general_word_comment'] = 'Комментарий';
$lang['general_word_general'] = 'Общее';
$lang['general_word_satellite'] = 'Спутник';
$lang['general_word_satellite_short'] = 'Спутн.';
$lang['general_word_notes'] = 'Заметки';
$lang['general_word_country'] = 'Страна';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Всего';
$lang['general_word_year'] = 'Год';
$lang['general_word_month'] = 'Месяц';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Сработано';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Подтверждено';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Необходимо';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Нет';
$lang['general_word_yes'] = 'Да';
$lang['general_word_method'] = 'Метод';

$lang['general_word_sent'] = 'Отправлено';
$lang['general_word_received'] = 'Принято';
$lang['general_word_requested'] = 'Запрошено';
$lang['general_word_queued'] = 'В очереди';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Некорректно (Игнорировать)';

$lang['general_word_qslcard'] = 'QSL карточка';
$lang['general_word_qslcard_management'] = 'QSL менеджемент';
$lang['general_word_qslcards'] = 'QSL карточки';
$lang['general_word_qslcard_direct'] = 'Напрямую';
$lang['general_word_qslcard_bureau'] = 'Бюро';
$lang['general_word_qslcard_electronic'] = 'Электронное';
$lang['general_word_qslcard_manager'] = 'Менеджер';
$lang['general_word_qslcard_via'] = 'через';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_qso_data'] = 'QSO Data';
$lang['general_word_details'] = 'Details';

$lang['general_edit_qso'] = 'Редактировать QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Отметить QSL полученной (через бюро)';
$lang['general_mark_qsl_rx_direct'] = 'Отметить QSL полученной (напрямую)';
$lang['general_mark_qsl_rx_electronic'] = 'Отметить QSL полученной (электронно)';
$lang['general_mark_qsl_tx_bureau'] = 'Отметить QSL отправленной (через бюро)';
$lang['general_mark_qsl_tx_direct'] = 'Отметить QSL отправленой (напрямую)';
$lang['general_mark_qsl_requested'] = 'Отметить запрос QSL-карточки';
$lang['general_mark_qsl_requested_bureau'] = 'Отметить запрос QSL-карточки (через бюро)';
$lang['general_mark_qsl_requested_direct'] = 'Отметить запрос QSL-карточки (напрямую)';
$lang['general_mark_qsl_not_required'] = 'Отметить QSL-карточка не требуется';

$lang['general_delete_qso'] = 'Удалить QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Суммарная дистанция';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Месторасположение станции';

$lang['gen_hamradio_cq'] = "CQ";
// ham radio terms
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Станция';

$lang['gen_hamradio_call'] = 'Позывной';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_callsign'] = 'Позывной';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Вид модуляции';
$lang['gen_hamradio_rst_sent'] = 'Отправлено';
$lang['gen_hamradio_rst_rcvd'] = 'Получено';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band'] = 'Диапазон';
$lang['gen_hamradio_band_rx'] = 'Диапазон (RX)';
$lang['gen_hamradio_frequency'] = 'Частота';
$lang['gen_hamradio_frequency_rx'] = 'Частота (RX)';
$lang['gen_hamradio_radio'] = 'Радио';
$lang['gen_hamradio_rsts'] = 'RST (отправлено)';
$lang['gen_hamradio_rstr'] = 'RST (принято)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Локатор';
$lang['gen_hamradio_transmit_power'] = 'Мощность передачи (Вт)';
$lang['gen_hamradio_propagation_mode'] = 'Тип прохождения';

$lang['gen_hamradio_satellite_name'] = 'Название спутника';
$lang['gen_hamradio_satellite_mode'] = 'Режим работы спутника';

$lang['gen_hamradio_award'] = "Award";
$lang['gen_hamradio_logbook'] = 'Журнал';
$lang['gen_hamradio_zones'] = 'Zones';

$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Удалённые DXCC';
$lang['gen_hamradio_continent'] = 'Континент';
$lang['gen_hamradio_usa_state'] = 'Штат США';
$lang['gen_hamradio_county_reference'] = 'Графство США';
$lang['gen_hamradio_iota_reference'] = 'IOTA справочник';
$lang['gen_hamradio_sota_reference'] = 'SOTA Справочник';
$lang['gen_hamradio_wwff_reference'] = 'WWFF справочник';
$lang['gen_hamradio_pota_reference'] = 'POTA справочник';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Штат';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_gridsquare'] = 'Квадрат';
$lang['gen_hamradio_distance'] = 'Дистанция';
$lang['gen_hamradio_operator'] = 'Оператор';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = '';
$lang['dashboard_qsos_today'] = 'QSOs сегодня!';
$lang['dashboard_qso_breakdown'] = 'Статистика QSO';
$lang['gen_to_date'] = 'To date';
$lang['dashboard_countries_breakdown'] = 'Статистика по странам';

$lang['gen_from_date'] = 'Начиная с даты';

$lang['gen_this_qso_was_confirmed_on'] = 'Это QSO было подтверждено:';

$lang['error_no_logbook_found'] = 'Журнал не найден. Вам необходимо опрелелить журнал в разделе Журналы станций! Тут:';

$lang['copy_to_clipboard'] = 'Скопировать в буфер обмена';

$lang['africa'] = 'Африка';
$lang['antarctica'] = 'Антарктика';
$lang['asia'] = 'Азия';
$lang['europe'] = 'Европа';
$lang['northamerica'] = 'Северная Америка';
$lang['oceania'] = 'Океания';
$lang['southamerica'] = 'Южная Америка';

$lang['gen_band_selection'] = 'Выбор диапазона';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';
